Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(354)

Unified Diff: sdk/lib/io/websocket_impl.dart

Issue 14251013: Rename unsubscribeOnError to cancelOnError. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/io/websocket_impl.dart
diff --git a/sdk/lib/io/websocket_impl.dart b/sdk/lib/io/websocket_impl.dart
index 356ca4a39b82aad10d10025806afaffb317cb827..1fa56ed1c02c5a44b0314a5642e6935613e84254 100644
--- a/sdk/lib/io/websocket_impl.dart
+++ b/sdk/lib/io/websocket_impl.dart
@@ -37,7 +37,7 @@ class _WebSocketOpcode {
* which is supplied through the [:handleData:]. As the protocol is processed,
* it'll output frame data as either a List<int> or String.
*
* Important infomation about usage: Be sure you use unsubscribeOnError, so the
* socket will be closed when the processer encounter an error. Not using it
* will lead to undefined behaviour.
*/
@@ -547,7 +547,7 @@ class _WebSocketImpl extends Stream implements WebSocket {
_controller.close();
if (_writeClosed) _socket.destroy();
},
- unsubscribeOnError: true);
+ cancelOnError: true);
_socket.done
.catchError((error) {
@@ -566,11 +566,11 @@ class _WebSocketImpl extends Stream implements WebSocket {
StreamSubscription listen(void onData(message),
{void onError(AsyncError error),
void onDone(),
- bool unsubscribeOnError}) {
+ bool cancelOnError}) {
return _controller.stream.listen(onData,
onError: onError,
onDone: onDone,
- unsubscribeOnError: unsubscribeOnError);
+ cancelOnError: cancelOnError);
}
int get readyState => _readyState;
@@ -37,7 +37,7 @@ class _WebSocketOpcode {
* it'll output frame data as either a List<int> or String.
*
- * Important infomation about usage: Be sure you use unsubscribeOnError, so the
+ * Important infomation about usage: Be sure you use cancelOnError, so the
* socket will be closed when the processer encounter an error. Not using it
* will lead to undefined behaviour.

Powered by Google App Engine
This is Rietveld 408576698